==> openjdk-src-13.0.1.u9-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_rn.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_rn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BIF", "FBu" },
            { "aed", "Idiramu ryo muri Leta Zunze Ubumwe z\u2019Abarabu" },
            { "aoa", "Ikwanza ryo muri Angola" },
            { "aud", "Idolari ryo muri Ositaraliya" },
            { "bhd", "Idinari ry\u2019iribahireyini" },
            { "bif", "Ifaranga ry\u2019Uburundi" },
            { "bwp", "Ipula ryo muri Botswana" },
            { "cad", "Idolari rya Kanada" },
            { "cdf", "Ifaranga rya Kongo" },
            { "chf", "Ifaranga ry\u2019Ubusuwisi" },
            { "cny", "Iyuwani ryo mu Bushinwa" },
            { "cve", "Irikaboveridiyano ryo muri Esikudo" },
            { "djf", "Ifaranga ryo muri Jibuti" },
            { "dzd", "Idinari ryo muri Alijeriya" },
            { "egp", "Ipawundi rya Misiri" },
            { "ern", "Irinakufa ryo muri Eritereya" },
            { "etb", "Ibiri ryo muri Etiyopiya" },
            { "eur", "Iyero" },
            { "gbp", "Ipawundi ryo mu Bwongereza" },
            { "ghc", "Icedi ryo muri Gana" },
            { "gmd", "Idalasi ryo muri Gambiya" },
            { "gns", "Ifaranga ryo muri Gineya" },
            { "inr", "Irupiya ryo mu Buhindi" },
            { "jpy", "Iyeni ry\u2019Ubuyapani" },
            { "kes", "Ishilingi rya Kenya" },
            { "kmf", "Ifaranga rya Komore" },
            { "lrd", "Idolari rya Liberiya" },
            { "lsl", "Iloti ryo muro Lesoto" },
            { "lyd", "Idinari rya Libiya" },
            { "mad", "Idiramu ryo muri Maroke" },
            { "mga", "Iriyari ryo muri Madagasikari" },
            { "mro", "Ugwiya ryo muri Moritaniya (1973\u20132017)" },
            { "mru", "Ugwiya ryo muri Moritaniya" },
            { "mur", "Irupiya ryo mu birwa bya Morise" },
            { "mwk", "Ikwaca ryo muri Malawi" },
            { "mzm", "Irimetikali ryo muri Mozambike" },
            { "nad", "Idolari rya Namibiya" },
            { "ngn", "Inayira ryo muri Nijeriya" },
            { "rwf", "Ifaranga ry\u2019u Rwanda" },
            { "sar", "Iriyari ryo muri Arabiya Sawudite" },
            { "scr", "Irupiya ryo mu birwa bya Sayisheli" },
            { "sdg", "Ipawundi rya Sudani" },
            { "shp", "Ipawundi rya Sente Helena" },
            { "sll", "Ilewone" },
            { "sos", "Ishilingi ryo muri Somaliya" },
            { "std", "Idobura ryo muri Sawotome na Perensipe (1977\u20132017)" },
            { "stn", "Idobura ryo muri Sawotome na Perensipe" },
            { "szl", "Ililangeni" },
            { "tnd", "Idinari ryo muri Tuniziya" },
            { "tzs", "Ishilingi rya Tanzaniya" },
            { "ugx", "Ishilingi ry\u2019Ubugande" },
            { "usd", "Idolari ry\u2019abanyamerika" },
            { "zar", "Irandi ryo muri Afurika y\u2019Epfo" },
            { "zmk", "Ikwaca ryo muri Zambiya (1968\u20132012)" },
            { "zmw", "Ikwaca ryo muri Zambiya" },
            { "zwd", "Idolari ryo muri Zimbabwe" },
        };
        return data;
    }
}

==> openjdk-src-24.0.2.u12-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_rn.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_rn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "BIF", "FBu" },
            { "aed", "Idiramu ryo muri Leta Zunze Ubumwe z\u2019Abarabu" },
            { "aoa", "Ikwanza ryo muri Angola" },
            { "aud", "Idolari ryo muri Ositaraliya" },
            { "bhd", "Idinari ry\u2019iribahireyini" },
            { "bif", "Ifaranga ry\u2019Uburundi" },
            { "bwp", "Ipula ryo muri Botswana" },
            { "cad", "Idolari rya Kanada" },
            { "cdf", "Ifaranga rya Kongo" },
            { "chf", "Ifaranga ry\u2019Ubusuwisi" },
            { "cny", "Iyuwani ryo mu Bushinwa" },
            { "cve", "Irikaboveridiyano ryo muri Esikudo" },
            { "djf", "Ifaranga ryo muri Jibuti" },
            { "dzd", "Idinari ryo muri Alijeriya" },
            { "egp", "Ipawundi rya Misiri" },
            { "ern", "Irinakufa ryo muri Eritereya" },
            { "etb", "Ibiri ryo muri Etiyopiya" },
            { "eur", "Iyero" },
            { "gbp", "Ipawundi ryo mu Bwongereza" },
            { "ghc", "Icedi ryo muri Gana" },
            { "gmd", "Idalasi ryo muri Gambiya" },
            { "gns", "Ifaranga ryo muri Gineya" },
            { "inr", "Irupiya ryo mu Buhindi" },
            { "jpy", "Iyeni ry\u2019Ubuyapani" },
            { "kes", "Ishilingi rya Kenya" },
            { "kmf", "Ifaranga rya Komore" },
            { "lrd", "Idolari rya Liberiya" },
            { "lsl", "Iloti ryo muro Lesoto" },
            { "lyd", "Idinari rya Libiya" },
            { "mad", "Idiramu ryo muri Maroke" },
            { "mga", "Iriyari ryo muri Madagasikari" },
            { "mro", "Ugwiya ryo muri Moritaniya (1973\u20132017)" },
            { "mru", "Ugwiya ryo muri Moritaniya" },
            { "mur", "Irupiya ryo mu birwa bya Morise" },
            { "mwk", "Ikwaca ryo muri Malawi" },
            { "mzm", "Irimetikali ryo muri Mozambike" },
            { "nad", "Idolari rya Namibiya" },
            { "ngn", "Inayira ryo muri Nijeriya" },
            { "rwf", "Ifaranga ry\u2019u Rwanda" },
            { "sar", "Iriyari ryo muri Arabiya Sawudite" },
            { "scr", "Irupiya ryo mu birwa bya Sayisheli" },
            { "sdg", "Ipawundi rya Sudani" },
            { "shp", "Ipawundi rya Sente Helena" },
            { "sle", "Ilewone" },
            { "sll", "Ilewone (1964\u20142022)" },
            { "sos", "Ishilingi ryo muri Somaliya" },
            { "std", "Idobura ryo muri Sawotome na Perensipe (1977\u20132017)" },
            { "stn", "Idobura ryo muri Sawotome na Perensipe" },
            { "szl", "Ililangeni" },
            { "tnd", "Idinari ryo muri Tuniziya" },
            { "tzs", "Ishilingi rya Tanzaniya" },
            { "ugx", "Ishilingi ry\u2019Ubugande" },
            { "usd", "Idolari ry\u2019abanyamerika" },
            { "zar", "Irandi ryo muri Afurika y\u2019Epfo" },
            { "zmk", "Ikwaca ryo muri Zambiya (1968\u20132012)" },
            { "zmw", "Ikwaca ryo muri Zambiya" },
            { "zwd", "Idolari ryo muri Zimbabwe" },
        };
        return data;
    }
}
